==> FuzzyImputationTest_0.5.1.tar.gz: FuzzyImputationTest/tests/testthat/_snaps/FuzzyImputation.md <==
# Function returns correct values

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testMatrix1NA)
    Output
      Iteration:  1 
                   [,1]         [,2]        [,3]         [,4]
       [1,]  0.11992398  0.188146026  0.31481645  0.454346750
       [2,] -0.40889518 -1.839384602  0.44777067  1.001830760
       [3,]  0.42779912  0.603188626  1.92344212  2.062777662
       [4,] -2.23286624 -2.042898771  0.35867035  0.907465245
       [5,] -2.56308080 -2.064273777 -1.23140885 -0.927024725
       [6,]  0.23239251  0.578480154  2.86563543  1.084108858
       [7,] -0.99073392 -0.617642400 -0.06840412  0.126227493
       [8,] -0.01765269  0.007461673  0.41849777  0.937398067
       [9,] -1.30063213 -1.275517766 -0.46704551 -0.236485501
      [10,] -3.61698093 -3.278239026 -1.14842928 -0.917869269
      [11,] -0.55735575 -0.548298205 -0.42162778 -0.303922994
      [12,] -1.65303313 -1.113884835 -0.22295531 -0.142508395
      [13,] -1.95278578 -1.698957584  0.58819769  0.609471724
      [14,] -1.50014617 -1.310178700 -0.03186601  0.008898696
      [15,] -0.45358837 -0.375611086  0.03542501  1.753746539
      [16,] -0.88923590 -1.284665217 -0.47619296 -0.029626635
      [17,]  1.92527091  2.115238384  3.00592957  3.082389607
      [18,]  0.90683695  1.160665144  1.54206699  1.736698607
      [19,] -0.89694909 -0.608124123  0.22474081  0.364076354
      [20,] -1.69647135 -1.350383708 -0.07207102  0.158488995

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testMatrix10NA, trapezoidal = FALSE)
    Output
      Iteration:  1 
                   [,1]         [,2]         [,3]
       [1,] -0.99866000 -0.853835182 -0.545485389
       [2,]  0.59225788  0.994879585  1.574799674
       [3,] -0.12634007  0.401619878  0.627165993
       [4,] -0.65826957 -0.183290977 -0.042520747
       [5,] -0.70264955 -0.115573742  0.003696135
       [6,] -1.69906601 -1.182500705 -0.820664650
       [7,] -0.30123316  0.265799467  0.512902081
       [8,]  0.08037545  0.375532485  0.683882278
       [9,]  1.16124804  1.456405083  1.818241138
      [10,] -0.51843848 -0.001873174  0.414649580
      [11,]  0.11637245  0.518994150  0.744540265
      [12,] -1.27432501 -0.848995095 -0.683944360
      [13,]  1.21186797  1.574381369  1.919502904
      [14,] -1.92788072 -1.497981828 -1.241472339
      [15,]  0.61843924  1.055793836  1.472316590
      [16,] -0.94067798 -0.503323381 -0.623535158
      [17,]  0.20970527  0.647059865  1.119213099
      [18,] -0.75934555 -0.571328407 -0.474394441
      [19,] -0.69297862 -0.330465218 -0.104919103
      [20,]  0.40530684  0.880285432  0.976037808

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testDataFrame1NA)
    Output
      Iteration:  1 
                     V1           V2          V3           V4
       [1,]  0.11992398  0.188146026  0.31481645  0.454346750
       [2,] -0.40889518 -1.839384602  0.44777067  1.001830760
       [3,]  0.42779912  0.603188626  1.92344212  2.062777662
       [4,] -2.23286624 -2.042898771  0.35867035  0.907465245
       [5,] -2.56308080 -2.064273777 -1.23140885 -0.927024725
       [6,]  0.23239251  0.578480154  2.86563543  1.084108858
       [7,] -0.99073392 -0.617642400 -0.06840412  0.126227493
       [8,] -0.01765269  0.007461673  0.41849777  0.937398067
       [9,] -1.30063213 -1.275517766 -0.46704551 -0.236485501
      [10,] -3.61698093 -3.278239026 -1.14842928 -0.917869269
      [11,] -0.55735575 -0.548298205 -0.42162778 -0.303922994
      [12,] -1.65303313 -1.113884835 -0.22295531 -0.142508395
      [13,] -1.95278578 -1.698957584  0.58819769  0.609471724
      [14,] -1.50014617 -1.310178700 -0.03186601  0.008898696
      [15,] -0.45358837 -0.375611086  0.03542501  1.753746539
      [16,] -0.88923590 -1.284665217 -0.47619296 -0.029626635
      [17,]  1.92527091  2.115238384  3.00592957  3.082389607
      [18,]  0.90683695  1.160665144  1.54206699  1.736698607
      [19,] -0.89694909 -0.608124123  0.22474081  0.364076354
      [20,] -1.69647135 -1.350383708 -0.07207102  0.158488995

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testDataFrame10NA, trapezoidal = FALSE)
    Output
      Iteration:  1 
                     V1           V2           V3
       [1,] -0.99866000 -0.853835182 -0.545485389
       [2,]  0.59225788  0.994879585  1.574799674
       [3,] -0.12634007  0.401619878  0.627165993
       [4,] -0.65826957 -0.183290977 -0.042520747
       [5,] -0.70264955 -0.115573742  0.003696135
       [6,] -1.69906601 -1.182500705 -0.820664650
       [7,] -0.30123316  0.265799467  0.512902081
       [8,]  0.08037545  0.375532485  0.683882278
       [9,]  1.16124804  1.456405083  1.818241138
      [10,] -0.51843848 -0.001873174  0.414649580
      [11,]  0.11637245  0.518994150  0.744540265
      [12,] -1.27432501 -0.848995095 -0.683944360
      [13,]  1.21186797  1.574381369  1.919502904
      [14,] -1.92788072 -1.497981828 -1.241472339
      [15,]  0.61843924  1.055793836  1.472316590
      [16,] -0.94067798 -0.503323381 -0.623535158
      [17,]  0.20970527  0.647059865  1.119213099
      [18,] -0.75934555 -0.571328407 -0.474394441
      [19,] -0.69297862 -0.330465218 -0.104919103
      [20,]  0.40530684  0.880285432  0.976037808

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testMatrix1NA, method = "missForest")
    Output
      Iteration:  1 
                   [,1]         [,2]        [,3]         [,4]
       [1,]  0.11992398  0.188146026  0.31481645  0.454346750
       [2,] -0.40889518 -0.217097660  0.44777067  1.001830760
       [3,]  0.42779912  0.603188626  1.92344212  2.062777662
       [4,] -2.23286624 -2.042898771  0.35867035  0.907465245
       [5,] -2.56308080 -2.064273777 -1.23140885 -0.927024725
       [6,]  0.23239251  0.120057993  0.54115286  1.084108858
       [7,] -0.99073392 -0.617642400 -0.06840412 -0.125378374
       [8,] -0.04488495  0.007461673  0.41849777  0.937398067
       [9,] -1.30063213 -1.275517766 -0.46704551 -0.027786842
      [10,] -3.61698093 -3.278239026 -1.14842928 -0.917869269
      [11,] -0.55735575 -0.602401157 -0.42162778 -0.303922994
      [12,] -1.65303313 -1.113884835 -0.22295531 -0.142508395
      [13,] -1.87261785 -1.698957584  0.58819769  0.609471724
      [14,] -1.34758356 -1.310178700 -0.34341711  0.008898696
      [15,] -0.45358837 -0.375611086  0.82995918  1.753746539
      [16,] -0.88923590 -0.754437178 -0.47619296 -0.029626635
      [17,]  0.60185429  2.115238384  3.00592957  3.082389607
      [18,]  0.90683695  1.160665144  1.54206699  1.736698607
      [19,] -0.89694909 -0.608124123 -0.32516946 -0.123738180
      [20,] -1.69647135 -1.350383708 -0.07207102 -0.052389161

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testMatrix10NA, method = "missForest",
        trapezoidal = FALSE)
    Output
      Iteration:  1 
                   [,1]         [,2]         [,3]
       [1,] -0.99866000 -0.853835182 -0.545485389
       [2,]  0.70262273  0.994879585  1.574799674
       [3,] -0.12634007  0.401619878  0.627165993
       [4,] -0.68529639 -0.183290977 -0.042520747
       [5,] -0.70264955 -0.115573742  0.003696135
       [6,] -1.69906601 -1.182500705 -0.820664650
       [7,] -0.30123316  0.265799467  0.512902081
       [8,] -0.06794971  0.425015835  0.683882278
       [9,]  1.16124804  1.456405083  1.770899764
      [10,] -0.63304214 -0.001873174 -0.026401783
      [11,]  0.11637245  0.518994150  0.852690141
      [12,] -1.27432501 -0.848995095 -0.683944360
      [13,]  1.21186797  1.308974809  1.919502904
      [14,] -1.92788072 -1.497981828 -1.241472339
      [15,]  0.61843924  1.055793836  1.472316590
      [16,] -0.94067798 -0.787815913 -0.623535158
      [17,]  0.20970527  0.713163005  1.119213099
      [18,] -0.75934555 -0.571328407 -0.474394441
      [19,] -0.69297862 -0.330465218 -0.066899302
      [20,]  0.40530684  0.880285432  0.976037808

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testDataFrame1NA, method = "missForest")
    Output
      Iteration:  1 
                     V1           V2          V3           V4
       [1,]  0.11992398  0.188146026  0.31481645  0.454346750
       [2,] -0.40889518 -0.217097660  0.44777067  1.001830760
       [3,]  0.42779912  0.603188626  1.92344212  2.062777662
       [4,] -2.23286624 -2.042898771  0.35867035  0.907465245
       [5,] -2.56308080 -2.064273777 -1.23140885 -0.927024725
       [6,]  0.23239251  0.120057993  0.54115286  1.084108858
       [7,] -0.99073392 -0.617642400 -0.06840412 -0.125378374
       [8,] -0.04488495  0.007461673  0.41849777  0.937398067
       [9,] -1.30063213 -1.275517766 -0.46704551 -0.027786842
      [10,] -3.61698093 -3.278239026 -1.14842928 -0.917869269
      [11,] -0.55735575 -0.602401157 -0.42162778 -0.303922994
      [12,] -1.65303313 -1.113884835 -0.22295531 -0.142508395
      [13,] -1.87261785 -1.698957584  0.58819769  0.609471724
      [14,] -1.34758356 -1.310178700 -0.34341711  0.008898696
      [15,] -0.45358837 -0.375611086  0.82995918  1.753746539
      [16,] -0.88923590 -0.754437178 -0.47619296 -0.029626635
      [17,]  0.60185429  2.115238384  3.00592957  3.082389607
      [18,]  0.90683695  1.160665144  1.54206699  1.736698607
      [19,] -0.89694909 -0.608124123 -0.32516946 -0.123738180
      [20,] -1.69647135 -1.350383708 -0.07207102 -0.052389161

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testDataFrame10NA, method = "missForest",
        trapezoidal = FALSE)
    Output
      Iteration:  1 
                     V1           V2           V3
       [1,] -0.99866000 -0.853835182 -0.545485389
       [2,]  0.70262273  0.994879585  1.574799674
       [3,] -0.12634007  0.401619878  0.627165993
       [4,] -0.68529639 -0.183290977 -0.042520747
       [5,] -0.70264955 -0.115573742  0.003696135
       [6,] -1.69906601 -1.182500705 -0.820664650
       [7,] -0.30123316  0.265799467  0.512902081
       [8,] -0.06794971  0.425015835  0.683882278
       [9,]  1.16124804  1.456405083  1.770899764
      [10,] -0.63304214 -0.001873174 -0.026401783
      [11,]  0.11637245  0.518994150  0.852690141
      [12,] -1.27432501 -0.848995095 -0.683944360
      [13,]  1.21186797  1.308974809  1.919502904
      [14,] -1.92788072 -1.497981828 -1.241472339
      [15,]  0.61843924  1.055793836  1.472316590
      [16,] -0.94067798 -0.787815913 -0.623535158
      [17,]  0.20970527  0.713163005  1.119213099
      [18,] -0.75934555 -0.571328407 -0.474394441
      [19,] -0.69297862 -0.330465218 -0.066899302
      [20,]  0.40530684  0.880285432  0.976037808

==> FuzzyImputationTest_0.5.2.tar.gz: FuzzyImputationTest/tests/testthat/_snaps/FuzzyImputation.md <==
# Function returns correct values

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testMatrix1NA)
    Output
      Iteration:  1 
                     X1           X2          X3           X4
       [1,]  0.11992398  0.188146026  0.31481645  0.454346750
       [2,] -0.40889518 -1.839384602  0.44777067  1.001830760
       [3,]  0.42779912  0.603188626  1.92344212  2.062777662
       [4,] -2.23286624 -2.042898771  0.35867035  0.907465245
       [5,] -2.56308080 -2.064273777 -1.23140885 -0.927024725
       [6,]  0.23239251  0.578480154  2.86563543  1.084108858
       [7,] -0.99073392 -0.617642400 -0.06840412  0.126227493
       [8,] -0.01765269  0.007461673  0.41849777  0.937398067
       [9,] -1.30063213 -1.275517766 -0.46704551 -0.236485501
      [10,] -3.61698093 -3.278239026 -1.14842928 -0.917869269
      [11,] -0.55735575 -0.548298205 -0.42162778 -0.303922994
      [12,] -1.65303313 -1.113884835 -0.22295531 -0.142508395
      [13,] -1.95278578 -1.698957584  0.58819769  0.609471724
      [14,] -1.50014617 -1.310178700 -0.03186601  0.008898696
      [15,] -0.45358837 -0.375611086  0.03542501  1.753746539
      [16,] -0.88923590 -1.284665217 -0.47619296 -0.029626635
      [17,]  1.92527091  2.115238384  3.00592957  3.082389607
      [18,]  0.90683695  1.160665144  1.54206699  1.736698607
      [19,] -0.89694909 -0.608124123  0.22474081  0.364076354
      [20,] -1.69647135 -1.350383708 -0.07207102  0.158488995

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testMatrix10NA, trapezoidal = FALSE)
    Output
      Iteration:  1 
                     X1           X2           X3
       [1,] -0.99866000 -0.853835182 -0.545485389
       [2,]  0.59225788  0.994879585  1.574799674
       [3,] -0.12634007  0.401619878  0.627165993
       [4,] -0.65826957 -0.183290977 -0.042520747
       [5,] -0.70264955 -0.115573742  0.003696135
       [6,] -1.69906601 -1.182500705 -0.820664650
       [7,] -0.30123316  0.265799467  0.512902081
       [8,]  0.08037545  0.375532485  0.683882278
       [9,]  1.16124804  1.456405083  1.818241138
      [10,] -0.51843848 -0.001873174  0.414649580
      [11,]  0.11637245  0.518994150  0.744540265
      [12,] -1.27432501 -0.848995095 -0.683944360
      [13,]  1.21186797  1.574381369  1.919502904
      [14,] -1.92788072 -1.497981828 -1.241472339
      [15,]  0.61843924  1.055793836  1.472316590
      [16,] -0.94067798 -0.503323381 -0.623535158
      [17,]  0.20970527  0.647059865  1.119213099
      [18,] -0.75934555 -0.571328407 -0.474394441
      [19,] -0.69297862 -0.330465218 -0.104919103
      [20,]  0.40530684  0.880285432  0.976037808

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testDataFrame1NA)
    Output
      Iteration:  1 
                     X1           X2          X3           X4
       [1,]  0.11992398  0.188146026  0.31481645  0.454346750
       [2,] -0.40889518 -1.839384602  0.44777067  1.001830760
       [3,]  0.42779912  0.603188626  1.92344212  2.062777662
       [4,] -2.23286624 -2.042898771  0.35867035  0.907465245
       [5,] -2.56308080 -2.064273777 -1.23140885 -0.927024725
       [6,]  0.23239251  0.578480154  2.86563543  1.084108858
       [7,] -0.99073392 -0.617642400 -0.06840412  0.126227493
       [8,] -0.01765269  0.007461673  0.41849777  0.937398067
       [9,] -1.30063213 -1.275517766 -0.46704551 -0.236485501
      [10,] -3.61698093 -3.278239026 -1.14842928 -0.917869269
      [11,] -0.55735575 -0.548298205 -0.42162778 -0.303922994
      [12,] -1.65303313 -1.113884835 -0.22295531 -0.142508395
      [13,] -1.95278578 -1.698957584  0.58819769  0.609471724
      [14,] -1.50014617 -1.310178700 -0.03186601  0.008898696
      [15,] -0.45358837 -0.375611086  0.03542501  1.753746539
      [16,] -0.88923590 -1.284665217 -0.47619296 -0.029626635
      [17,]  1.92527091  2.115238384  3.00592957  3.082389607
      [18,]  0.90683695  1.160665144  1.54206699  1.736698607
      [19,] -0.89694909 -0.608124123  0.22474081  0.364076354
      [20,] -1.69647135 -1.350383708 -0.07207102  0.158488995

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testDataFrame10NA, trapezoidal = FALSE)
    Output
      Iteration:  1 
                     X1           X2           X3
       [1,] -0.99866000 -0.853835182 -0.545485389
       [2,]  0.59225788  0.994879585  1.574799674
       [3,] -0.12634007  0.401619878  0.627165993
       [4,] -0.65826957 -0.183290977 -0.042520747
       [5,] -0.70264955 -0.115573742  0.003696135
       [6,] -1.69906601 -1.182500705 -0.820664650
       [7,] -0.30123316  0.265799467  0.512902081
       [8,]  0.08037545  0.375532485  0.683882278
       [9,]  1.16124804  1.456405083  1.818241138
      [10,] -0.51843848 -0.001873174  0.414649580
      [11,]  0.11637245  0.518994150  0.744540265
      [12,] -1.27432501 -0.848995095 -0.683944360
      [13,]  1.21186797  1.574381369  1.919502904
      [14,] -1.92788072 -1.497981828 -1.241472339
      [15,]  0.61843924  1.055793836  1.472316590
      [16,] -0.94067798 -0.503323381 -0.623535158
      [17,]  0.20970527  0.647059865  1.119213099
      [18,] -0.75934555 -0.571328407 -0.474394441
      [19,] -0.69297862 -0.330465218 -0.104919103
      [20,]  0.40530684  0.880285432  0.976037808

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testMatrix1NA, method = "missForest")
    Output
      Iteration:  1 
                     X1           X2          X3           X4
       [1,]  0.11992398  0.188146026  0.31481645  0.454346750
       [2,] -0.40889518 -0.049304152  0.44777067  1.001830760
       [3,]  0.42779912  0.603188626  1.92344212  2.062777662
       [4,] -2.23286624 -2.042898771  0.35867035  0.907465245
       [5,] -2.56308080 -2.064273777 -1.23140885 -0.927024725
       [6,]  0.23239251  0.262886486  0.95350539  1.084108858
       [7,] -0.99073392 -0.617642400 -0.06840412 -0.020262278
       [8,] -0.29813072  0.007461673  0.41849777  0.937398067
       [9,] -1.30063213 -1.275517766 -0.46704551 -0.124698010
      [10,] -3.61698093 -3.278239026 -1.14842928 -0.917869269
      [11,] -0.55735575 -0.674217735 -0.42162778 -0.303922994
      [12,] -1.65303313 -1.113884835 -0.22295531 -0.142508395
      [13,] -1.49226726 -1.698957584  0.58819769  0.609471724
      [14,] -1.56853549 -1.310178700 -0.16628474  0.008898696
      [15,] -0.45358837 -0.375611086  0.93862246  1.753746539
      [16,] -0.88923590 -0.889578122 -0.47619296 -0.029626635
      [17,] -0.02197023  2.115238384  3.00592957  3.082389607
      [18,]  0.90683695  1.160665144  1.54206699  1.736698607
      [19,] -0.89694909 -0.608124123  0.27449633  0.446679097
      [20,] -1.69647135 -1.350383708 -0.07207102 -0.157498795

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testMatrix10NA, method = "missForest",
        trapezoidal = FALSE)
    Output
      Iteration:  1 
                    X1           X2           X3
       [1,] -0.9986600 -0.853835182 -0.545485389
       [2,]  0.4748195  0.994879585  1.574799674
       [3,] -0.1263401  0.401619878  0.627165993
       [4,] -0.9049904 -0.183290977 -0.042520747
       [5,] -0.7026495 -0.115573742  0.003696135
       [6,] -1.6990660 -1.182500705 -0.820664650
       [7,] -0.3012332  0.265799467  0.512902081
       [8,]  0.2603596  0.670957844  0.683882278
       [9,]  1.1612480  1.456405083  1.153338848
      [10,] -0.8099805 -0.001873174 -0.325024376
      [11,]  0.1163724  0.518994150  1.064810621
      [12,] -1.2743250 -0.848995095 -0.683944360
      [13,]  1.2118680  0.753274638  1.919502904
      [14,] -1.9278807 -1.497981828 -1.241472339
      [15,]  0.6184392  1.055793836  1.472316590
      [16,] -0.9406780 -0.676371090 -0.623535158
      [17,]  0.2097053  0.742910907  1.119213099
      [18,] -0.7593456 -0.571328407 -0.474394441
      [19,] -0.6929786 -0.330465218 -0.456393564
      [20,]  0.4053068  0.880285432  0.976037808

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testDataFrame1NA, method = "missForest")
    Output
      Iteration:  1 
                     X1           X2          X3           X4
       [1,]  0.11992398  0.188146026  0.31481645  0.454346750
       [2,] -0.40889518 -0.049304152  0.44777067  1.001830760
       [3,]  0.42779912  0.603188626  1.92344212  2.062777662
       [4,] -2.23286624 -2.042898771  0.35867035  0.907465245
       [5,] -2.56308080 -2.064273777 -1.23140885 -0.927024725
       [6,]  0.23239251  0.262886486  0.95350539  1.084108858
       [7,] -0.99073392 -0.617642400 -0.06840412 -0.020262278
       [8,] -0.29813072  0.007461673  0.41849777  0.937398067
       [9,] -1.30063213 -1.275517766 -0.46704551 -0.124698010
      [10,] -3.61698093 -3.278239026 -1.14842928 -0.917869269
      [11,] -0.55735575 -0.674217735 -0.42162778 -0.303922994
      [12,] -1.65303313 -1.113884835 -0.22295531 -0.142508395
      [13,] -1.49226726 -1.698957584  0.58819769  0.609471724
      [14,] -1.56853549 -1.310178700 -0.16628474  0.008898696
      [15,] -0.45358837 -0.375611086  0.93862246  1.753746539
      [16,] -0.88923590 -0.889578122 -0.47619296 -0.029626635
      [17,] -0.02197023  2.115238384  3.00592957  3.082389607
      [18,]  0.90683695  1.160665144  1.54206699  1.736698607
      [19,] -0.89694909 -0.608124123  0.27449633  0.446679097
      [20,] -1.69647135 -1.350383708 -0.07207102 -0.157498795

---

    Code
      set.seed(123456)
      FuzzyImputation(dataToImpute = testDataFrame10NA, method = "missForest",
        trapezoidal = FALSE)
    Output
      Iteration:  1 
                    X1           X2           X3
       [1,] -0.9986600 -0.853835182 -0.545485389
       [2,]  0.4748195  0.994879585  1.574799674
       [3,] -0.1263401  0.401619878  0.627165993
       [4,] -0.9049904 -0.183290977 -0.042520747
       [5,] -0.7026495 -0.115573742  0.003696135
       [6,] -1.6990660 -1.182500705 -0.820664650
       [7,] -0.3012332  0.265799467  0.512902081
       [8,]  0.2603596  0.670957844  0.683882278
       [9,]  1.1612480  1.456405083  1.153338848
      [10,] -0.8099805 -0.001873174 -0.325024376
      [11,]  0.1163724  0.518994150  1.064810621
      [12,] -1.2743250 -0.848995095 -0.683944360
      [13,]  1.2118680  0.753274638  1.919502904
      [14,] -1.9278807 -1.497981828 -1.241472339
      [15,]  0.6184392  1.055793836  1.472316590
      [16,] -0.9406780 -0.676371090 -0.623535158
      [17,]  0.2097053  0.742910907  1.119213099
      [18,] -0.7593456 -0.571328407 -0.474394441
      [19,] -0.6929786 -0.330465218 -0.456393564
      [20,]  0.4053068  0.880285432  0.976037808
